/*****************************************************************************
 * Copyright (C) The Apache Software Foundation. All rights reserved.        *
 * ------------------------------------------------------------------------- *
 * This software is published under the terms of the Apache Software License *
 * version 1.1, a copy of which has been included with this distribution in  *
 * the LICENSE file.                                                         *
 *****************************************************************************/

package org.apache.batik.css.value;

import org.apache.batik.css.PropertyMap;
import org.w3c.css.sac.Parser;
import org.w3c.dom.css.CSSPrimitiveValue;

/**
 * This class provides a factory for the 'unicode-bidi' property values.
 *
 * @author <a href="mailto:stephane@hillion.org">Stephane Hillion</a>
 * @version $Id: UnicodeBidiFactory.java,v 1.2 2000/11/27 05:49:18 hillion Exp $
 */
public class UnicodeBidiFactory
    extends    AbstractIdentifierFactory
    implements ValueConstants {

    /**
     * The identifier values.
     */
    protected final static PropertyMap values = new PropertyMap();
    static {
	values.put(CSS_BIDI_OVERRIDE_VALUE, BIDI_OVERRIDE_VALUE);
	values.put(CSS_EMBED_VALUE,         EMBED_VALUE);
	values.put(CSS_NORMAL_VALUE,        NORMAL_VALUE);
    }

    /**
     * Creates a new UnicodeBidiFactory object.
     * @param p The CSS parser used to parse the CSS texts.
     */
    public UnicodeBidiFactory(Parser p) {
	super(p);
    }

    /**
     * Returns the name of the property handled.
     */
    public String getPropertyName() {
	return CSS_UNICODE_BIDI_PROPERTY;
    }
    
    /**
     * Returns the property map that contains the possible values.
     */
    protected PropertyMap getIdentifiers() {
	return values;
    }
}
